@@ -15,12 +15,11 @@ use std::{
 use serde::Deserialize;
 use serde_json::{Number, Value};
 use windows::{
-    runtime::*,
+    core::*,
     Win32::{
-        Foundation::{E_POINTER, HWND, LPARAM, LRESULT, PSTR, SIZE, WPARAM},
+        Foundation::{E_POINTER, HWND, LPARAM, LRESULT, PSTR, PWSTR, RECT, SIZE, WPARAM},
         Graphics::Gdi,
-        System::Com::*,
-        System::{LibraryLoader, Threading},
+        System::{Com::*, LibraryLoader, Threading, WinRT::EventRegistrationToken},
         UI::{
             HiDpi,
             Input::KeyboardAndMouse,
@@ -29,14 +28,7 @@ use windows::{
     },
 };
 
-use webview2_com::{
-    Microsoft::Web::WebView2::Win32::*,
-    Windows::Win32::{
-        Foundation::{PWSTR, RECT},
-        System::WinRT::EventRegistrationToken,
-    },
-    *,
-};
+use webview2_com::{Microsoft::Web::WebView2::Win32::*, *};
 
 fn main() -> Result<()> {
     unsafe {
@@ -65,11 +57,11 @@ fn main() -> Result<()> {
 
     // Configure the target URL and add an init script to trigger the calculator callback.
     webview
-        .set_title("WebView2-Win32 Example (examples/webview2-win32)")?
+        .set_title("webview2-com example (crates/webview2-com/examples)")?
         .init(
             r#"window.hostCallback("Add", 2, 6).then(result => console.log(`Result: ${result}`));"#,
         )?
-        .navigate("https://github.com/microsoft/windows-rs")?;
+        .navigate("https://github.com/wravery/webview2-rs")?;
 
     // Off we go....
     webview.run()
@@ -78,7 +70,7 @@ fn main() -> Result<()> {
 #[derive(Debug)]
 pub enum Error {
     WebView2Error(webview2_com::Error),
-    WindowsError(windows::runtime::Error),
+    WindowsError(windows::core::Error),
     JsonError(serde_json::Error),
     LockError,
 }
@@ -95,15 +87,15 @@ impl From<webview2_com::Error> for Error {
     }
 }
 
-impl From<windows::runtime::Error> for Error {
-    fn from(err: windows::runtime::Error) -> Self {
+impl From<windows::core::Error> for Error {
+    fn from(err: windows::core::Error) -> Self {
         Self::WindowsError(err)
     }
 }
 
 impl From<HRESULT> for Error {
     fn from(err: HRESULT) -> Self {
-        Self::WindowsError(windows::runtime::Error::fast_error(err))
+        Self::WindowsError(windows::core::Error::fast_error(err))
     }
 }
 
@@ -234,10 +226,8 @@ impl WebView {
                 }),
                 Box::new(move |error_code, environment| {
                     error_code?;
-                    tx.send(
-                        environment.ok_or_else(|| windows::runtime::Error::fast_error(E_POINTER)),
-                    )
-                    .expect("send over mpsc channel");
+                    tx.send(environment.ok_or_else(|| windows::core::Error::fast_error(E_POINTER)))
+                        .expect("send over mpsc channel");
                     Ok(())
                 }),
             )?;
@@ -252,18 +242,13 @@ impl WebView {
             CreateCoreWebView2ControllerCompletedHandler::wait_for_async_operation(
                 Box::new(move |handler| unsafe {
                     environment
-                        .CreateCoreWebView2Controller(
-                            webview2_com_sys::Windows::Win32::Foundation::HWND(parent.0),
-                            handler,
-                        )
+                        .CreateCoreWebView2Controller(parent, handler)
                         .map_err(webview2_com::Error::WindowsError)
                 }),
                 Box::new(move |error_code, controller| {
                     error_code?;
-                    tx.send(
-                        controller.ok_or_else(|| windows::runtime::Error::fast_error(E_POINTER)),
-                    )
-                    .expect("send over mpsc channel");
+                    tx.send(controller.ok_or_else(|| windows::core::Error::fast_error(E_POINTER)))
+                        .expect("send over mpsc channel");
                     Ok(())
                 }),
             )?;
@@ -401,7 +386,7 @@ impl WebView {
                 let result = WindowsAndMessaging::GetMessageA(&mut msg, h_wnd, 0, 0).0;
 
                 match result {
-                    -1 => break Err(windows::runtime::Error::from_win32().into()),
+                    -1 => break Err(windows::core::Error::from_win32().into()),
                     0 => break Ok(()),
                     _ => match msg.message {
                         WindowsAndMessaging::WM_APP => (),
@@ -514,8 +499,8 @@ impl WebView {
             WindowsAndMessaging::PostThreadMessageA(
                 self.thread_id,
                 WindowsAndMessaging::WM_APP,
-                WPARAM(0),
-                LPARAM(0),
+                WPARAM::default(),
+                LPARAM::default(),
             );
         }
         Ok(self)
@@ -642,19 +627,19 @@ extern "system" fn window_proc(hwnd: HWND, msg: u32, w_param: WPARAM, l_param: L
                     .unwrap();
             }
             *frame.size.lock().expect("lock size") = size;
-            LRESULT(0)
+            LRESULT::default()
         }
 
         WindowsAndMessaging::WM_CLOSE => {
             unsafe {
                 WindowsAndMessaging::DestroyWindow(hwnd);
             }
-            LRESULT(0)
+            LRESULT::default()
         }
 
         WindowsAndMessaging::WM_DESTROY => {
             webview.terminate().expect("window is gone");
-            LRESULT(0)
+            LRESULT::default()
         }
 
         _ => unsafe { WindowsAndMessaging::DefWindowProcA(hwnd, msg, w_param, l_param) },
